==> error404-1.1.tar.gz: error404-1.1/README.md <==
# error404

[![LGTM Grade](https://img.shields.io/lgtm/grade/python/g/harens/error404.svg?style=for-the-badge)](https://lgtm.com/projects/g/harens/error404/overview/)
[![Code Climate maintainability](https://img.shields.io/codeclimate/maintainability/harens/error404.svg?style=for-the-badge)](https://codeclimate.com/github/harens/error404)
[![Codacy grade](https://img.shields.io/codacy/grade/6e4af45add524fbc8b173760e5a72eb0.svg?style=for-the-badge)](https://app.codacy.com/project/harens/error404/dashboard)
[![Latest PyPi release version number](https://img.shields.io/pypi/v/error404.svg?logoColor=violet&style=for-the-badge)](https://pypi.org/project/error404/)
[![PyPi format](https://img.shields.io/pypi/format/error404.svg?style=for-the-badge)](https://pypi.org/project/error404/)
[![Current state (Alpha/Beta/Stable etc.)](https://img.shields.io/pypi/status/error404.svg?style=for-the-badge)](https://pypi.org/project/error404/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/error404.svg?style=for-the-badge)](https://pypi.org/project/error404/)

__Colourful tests for Python!__

![Example 1](https://github.com/harens/error404/blob/master/art/example1.png)

## Installation
```
pip install error404
```

Or download the project [here](https://github.com/harens/error404/archive/master.zip)

## Example

*This produces the output shown above 👆*

![Example 1 Code](https://github.com/harens/error404/blob/master/art/example1_code.png)

## License

This project is licensed under the [GNU General Public License v3.0](https://github.com/harens/error404/blob/master/LICENSE)

==> error404-1.1.7.tar.gz: error404-1.1.7/README.md <==
# error404

[![LGTM Grade](https://img.shields.io/lgtm/grade/python/g/harens/error404.svg?style=for-the-badge)](https://lgtm.com/projects/g/harens/error404/overview/)
[![Code Climate maintainability](https://img.shields.io/codeclimate/maintainability/harens/error404.svg?style=for-the-badge)](https://codeclimate.com/github/harens/error404)
[![Codacy grade](https://img.shields.io/codacy/grade/6e4af45add524fbc8b173760e5a72eb0.svg?style=for-the-badge)](https://app.codacy.com/project/harens/error404/dashboard)
[![Latest PyPi release version number](https://img.shields.io/pypi/v/error404.svg?logoColor=violet&style=for-the-badge)](https://pypi.org/project/error404/)
[![PyPi format](https://img.shields.io/pypi/format/error404.svg?style=for-the-badge)](https://pypi.org/project/error404/)
[![Current state (Alpha/Beta/Stable etc.)](https://img.shields.io/pypi/status/error404.svg?style=for-the-badge)](https://pypi.org/project/error404/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/error404.svg?style=for-the-badge)](https://pypi.org/project/error404/)

__Colourful tests for Python!__

![Example 1](https://raw.githubusercontent.com/harens/error404/master/art/example1.png)

## Installation
```
pip install error404
```

Or download the project [here](https://github.com/harens/error404/archive/master.zip)

## Examples

### From a File
*The examples produce the output shown above 👆*

![Example 1 Code](https://raw.githubusercontent.com/harens/error404/master/art/example1_code.png)

## License

This project is licensed under the [GNU General Public License v3.0](https://github.com/harens/error404/blob/master/LICENSE)
